Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(136)

Unified Diff: src/execution.cc

Issue 796623003: Support multiple interrupt requests in v8 API. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/api.cc ('k') | src/isolate.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/execution.cc
diff --git a/src/execution.cc b/src/execution.cc
index cfe61f963a87d41e86e153d2104bdc0791783c63..217e82b45b3792a2feb8cd21aac5c69634e01b03 100644
--- a/src/execution.cc
+++ b/src/execution.cc
@@ -707,8 +707,8 @@ Object* StackGuard::HandleInterrupts() {
}
if (CheckAndClearInterrupt(API_INTERRUPT)) {
- // Callback must be invoked outside of ExecusionAccess lock.
- isolate_->InvokeApiInterruptCallback();
+ // Callbacks must be invoked outside of ExecusionAccess lock.
+ isolate_->InvokeApiInterruptCallbacks();
}
isolate_->counters()->stack_interrupts()->Increment();
« no previous file with comments | « src/api.cc ('k') | src/isolate.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698